#include <18F458.h>
#device adc=8
#FUSES WDT64                     //Watch Dog Timer uses 1:1 Postscale
#FUSES H4                       //High speed osc with HW enabled 4X PLL
#FUSES NOPROTECT                //Code not protected from reading
#FUSES NOOSCSEN                 //Oscillator switching is disabled, main oscillator is source
#FUSES BROWNOUT                 //Reset when brownout detected
#FUSES BORV27                   //Brownout reset at 2.7V
#FUSES PUT                      //Power Up Timer
#FUSES NOCPD                    //No EE protection
#FUSES STVREN                   //Stack full/underflow will cause reset
#FUSES NODEBUG                  //No Debug mode for ICD
#FUSES NOLVP                    //No low voltage prgming, B3(PIC16) or B5(PIC18) used for I/O
#FUSES NOWRT                    //Program memory not write protected
#FUSES NOWRTD                   //Data EEPROM not write protected
#FUSES NOWRTB                   //Boot block not write protected
#FUSES NOCPB                    //No Boot Block code protection
#FUSES NOWRTC                   //configuration not registers write protected
#FUSES NOEBTR                   //Memory not protected from table reads
#FUSES NOEBTRB                  //Boot block not protected from table reads
#use delay(clock=40000000,RESTART_WDT)
#use fast_io(A) //     
#use fast_io(B) //    TRIS
#use STANDARD_IO (C) // 
#USE STANDARD_IO (D) // 
//#define __PCH__
/*
;               PIC18F458 I/O
;                +---------------   ---------------+
;   +5v 510R    -|MCLR/Vpp                  RB7/PGD|-  
;   Led         -|RA0/AN0/Cvref             RB6/PGC|-  
;               -|RA1/AN1                   RB5/PGM|-  
;               -|RA2/AN2/Vref-             RB4    |-  
;               -|RA3/AN3/Vref+           RB3/CANRX|-  
;               -|Ra4/TOCKI          RB2/CANTX/INT2|-  
;               -|RA5/AN4/SS/LVDIN         RB1/INT1|-  
;               -|RE0/AN5/RD               RB0/INT0|-  
;               -|RE1/AN6/WR/C1OUT          Vdd    |-  +5V
;               -|RE2/AN7/CS/C2OUT          Vss    |-  GND
;   +5V         -|Vdd                  RD7/PSP7/P1D|-  LCD DB7
;   GND         -|Vss                  RD6/PSP6/P1C|-  LCD DB6
;   XTAL        -|OSC1/CLKI            RD5/PSP5/P1B|-  LCD DB5
;   XTAL        -|OSC2/CLKO/RA6  RD4/PSP4/ECCP1/P1A|-  LCD DB4
;               -|RC0/T1OSO/T1CKI       RC7/RX/DT  |-  
;               -|RC1/T1OSI             RC6/TX/CK  |-  
;               -|RC2/CCP1              RC5/SDO    |-  
;               -|RC3/SCK/SCL           RC4/SDI/SDA|-  
;   LCD E       -|RD0/PSP0/C1IN+     RD3/PSP3/C2IN-|- 
;   LCD R/S     -|RD1/PSP1/C1IN-     RD2/PSP2/C2IN+|- (LCD R/W)
;                +---------------   ---------------+
*/
#include <LCD.C> //   LCD HD44780
#include <9346.C> //    EEPROM
#define LED PIN_A0  //  
#define  use_portd_lcd == TRUE
#define LCD_ENABLE_PIN  PIN_D0
#define LCD_RS_PIN      PIN_D1
#define LCD_RW_PIN      PIN_D2
#define LCD_DATA4       PIN_D4
#define LCD_DATA5       PIN_D5
#define LCD_DATA6       PIN_D6
#define LCD_DATA7       PIN_D7
#define EEPROM_SELECT PIN_C7
#define EEPROM_CLK    PIN_C6
#define EEPROM_DI     PIN_C5
#define EEPROM_DO     PIN_C4
// ===============    ========================
register byte Buff[8] = {0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F};
register byte LCD_Data[8] = {0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07};
register byte LCD_Data1[8] = {0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F};
byte *LCD_Dat = &LCD_Data; //    8  hex  LCD
byte *LCD_Dat1 = &LCD_Data1; //     8  hex  LCD
byte *addr;
byte eeadr;
register byte del;
//================    ===============================
void LCD_INDICATED(byte Buff[]); //   16 
void LCD_IND_DATA(byte LCD_Data[], byte *LCD_Dat); //  8  hex 
byte EEPROM_RD(byte eeadr, byte *addr); //   EEPROM 8  
byte EEPROM_WR(byte eeadr, byte *addr); //   EEPROM 8  
void EXT_EEPROM_WR(void);
void FASH_LED(byte del); //     del 
//
void FASH_LED (del) { 
    while(del != 0){
         output_low(LED);
      delay_ms(1);
      restart_wdt();
      output_high(LED);
      delay_ms(1);
      restart_wdt();
      del --;
}
      return;
}
void main(){
   port_b_pullups(TRUE);
   setup_adc_ports(NO_ANALOGS);
   setup_adc(ADC_OFF);
   setup_psp(PSP_DISABLED);
   setup_spi(SPI_SS_DISABLED);
   setup_wdt(WDT_ON);
   setup_timer_0(RTCC_INTERNAL);
   setup_timer_1(T1_DISABLED);
   setup_timer_2(T2_DISABLED,0,1);
   setup_timer_3(T3_DISABLED|T3_DIV_BY_1);
   setup_ccp1(CCP_OFF);
   setup_comparator(NC_NC_NC_NC);
   setup_vref(FALSE);
   setup_low_volt_detect(FALSE);
	EXT_EEPROM_WR();
	lcd_init();            //  LCD
	lcd_gotoxy(1,1);      //  
	delay_us(1);			// 
//   EEPROM  8-   Buff
   for(addr = &Buff, eeadr = 0x00; addr <= (&Buff + 0x0F); addr ++){
		restart_wdt();
		write_eeprom(eeadr, *addr);
		eeadr ++;}
		FASH_LED(8);
}
//    8    hex  (16 )
void LCD_IND_DATA(LCD_Data[], *LCD_Dat) {
	unsigned int8 i;
	for(i=0; i<8; i++) printf(lcd_putc,"%X",*LCD_Dat++);
}
//   Buff   EEPROM
void EXT_EEPROM_WR() {
	unsigned int8 i;
	unsigned int8 address=0x00;
	*addr=&Buff;
	for(i=0; i<8; i++) {
	write_ext_eeprom(address, *addr);
	address++;
	*addr++;
}
}
// 
